# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class CreditNote(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "type": "str",
        "contact": "Contact",
        "date": "date[ms-format]",
        "due_date": "date[ms-format]",
        "status": "str",
        "line_amount_types": "LineAmountTypes",
        "line_items": "list[LineItem]",
        "sub_total": "float",
        "total_tax": "float",
        "total": "float",
        "cis_deduction": "float",
        "cis_rate": "float",
        "updated_date_utc": "datetime[ms-format]",
        "currency_code": "CurrencyCode",
        "fully_paid_on_date": "date[ms-format]",
        "credit_note_id": "str",
        "credit_note_number": "str",
        "reference": "str",
        "sent_to_contact": "bool",
        "currency_rate": "float",
        "remaining_credit": "float",
        "allocations": "list[Allocation]",
        "applied_amount": "float",
        "payments": "list[Payment]",
        "branding_theme_id": "str",
        "status_attribute_string": "str",
        "has_attachments": "bool",
        "has_errors": "bool",
        "validation_errors": "list[ValidationError]",
        "warnings": "list[ValidationError]",
    }

    attribute_map = {
        "type": "Type",
        "contact": "Contact",
        "date": "Date",
        "due_date": "DueDate",
        "status": "Status",
        "line_amount_types": "LineAmountTypes",
        "line_items": "LineItems",
        "sub_total": "SubTotal",
        "total_tax": "TotalTax",
        "total": "Total",
        "cis_deduction": "CISDeduction",
        "cis_rate": "CISRate",
        "updated_date_utc": "UpdatedDateUTC",
        "currency_code": "CurrencyCode",
        "fully_paid_on_date": "FullyPaidOnDate",
        "credit_note_id": "CreditNoteID",
        "credit_note_number": "CreditNoteNumber",
        "reference": "Reference",
        "sent_to_contact": "SentToContact",
        "currency_rate": "CurrencyRate",
        "remaining_credit": "RemainingCredit",
        "allocations": "Allocations",
        "applied_amount": "AppliedAmount",
        "payments": "Payments",
        "branding_theme_id": "BrandingThemeID",
        "status_attribute_string": "StatusAttributeString",
        "has_attachments": "HasAttachments",
        "has_errors": "HasErrors",
        "validation_errors": "ValidationErrors",
        "warnings": "Warnings",
    }

    def __init__(
        self,
        type=None,
        contact=None,
        date=None,
        due_date=None,
        status=None,
        line_amount_types=None,
        line_items=None,
        sub_total=None,
        total_tax=None,
        total=None,
        cis_deduction=None,
        cis_rate=None,
        updated_date_utc=None,
        currency_code=None,
        fully_paid_on_date=None,
        credit_note_id=None,
        credit_note_number=None,
        reference=None,
        sent_to_contact=None,
        currency_rate=None,
        remaining_credit=None,
        allocations=None,
        applied_amount=None,
        payments=None,
        branding_theme_id=None,
        status_attribute_string=None,
        has_attachments=False,
        has_errors=False,
        validation_errors=None,
        warnings=None,
    ):  # noqa: E501
        """CreditNote - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._contact = None
        self._date = None
        self._due_date = None
        self._status = None
        self._line_amount_types = None
        self._line_items = None
        self._sub_total = None
        self._total_tax = None
        self._total = None
        self._cis_deduction = None
        self._cis_rate = None
        self._updated_date_utc = None
        self._currency_code = None
        self._fully_paid_on_date = None
        self._credit_note_id = None
        self._credit_note_number = None
        self._reference = None
        self._sent_to_contact = None
        self._currency_rate = None
        self._remaining_credit = None
        self._allocations = None
        self._applied_amount = None
        self._payments = None
        self._branding_theme_id = None
        self._status_attribute_string = None
        self._has_attachments = None
        self._has_errors = None
        self._validation_errors = None
        self._warnings = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if contact is not None:
            self.contact = contact
        if date is not None:
            self.date = date
        if due_date is not None:
            self.due_date = due_date
        if status is not None:
            self.status = status
        if line_amount_types is not None:
            self.line_amount_types = line_amount_types
        if line_items is not None:
            self.line_items = line_items
        if sub_total is not None:
            self.sub_total = sub_total
        if total_tax is not None:
            self.total_tax = total_tax
        if total is not None:
            self.total = total
        if cis_deduction is not None:
            self.cis_deduction = cis_deduction
        if cis_rate is not None:
            self.cis_rate = cis_rate
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if currency_code is not None:
            self.currency_code = currency_code
        if fully_paid_on_date is not None:
            self.fully_paid_on_date = fully_paid_on_date
        if credit_note_id is not None:
            self.credit_note_id = credit_note_id
        if credit_note_number is not None:
            self.credit_note_number = credit_note_number
        if reference is not None:
            self.reference = reference
        if sent_to_contact is not None:
            self.sent_to_contact = sent_to_contact
        if currency_rate is not None:
            self.currency_rate = currency_rate
        if remaining_credit is not None:
            self.remaining_credit = remaining_credit
        if allocations is not None:
            self.allocations = allocations
        if applied_amount is not None:
            self.applied_amount = applied_amount
        if payments is not None:
            self.payments = payments
        if branding_theme_id is not None:
            self.branding_theme_id = branding_theme_id
        if status_attribute_string is not None:
            self.status_attribute_string = status_attribute_string
        if has_attachments is not None:
            self.has_attachments = has_attachments
        if has_errors is not None:
            self.has_errors = has_errors
        if validation_errors is not None:
            self.validation_errors = validation_errors
        if warnings is not None:
            self.warnings = warnings

    @property
    def type(self):
        """Gets the type of this CreditNote.  # noqa: E501

        See Credit Note Types  # noqa: E501

        :return: The type of this CreditNote.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreditNote.

        See Credit Note Types  # noqa: E501

        :param type: The type of this CreditNote.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACCPAYCREDIT", "ACCRECCREDIT", "None"]  # noqa: E501

        if type:
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                        type, allowed_values
                    )
                )

        self._type = type

    @property
    def contact(self):
        """Gets the contact of this CreditNote.  # noqa: E501


        :return: The contact of this CreditNote.  # noqa: E501
        :rtype: Contact
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """Sets the contact of this CreditNote.


        :param contact: The contact of this CreditNote.  # noqa: E501
        :type: Contact
        """

        self._contact = contact

    @property
    def date(self):
        """Gets the date of this CreditNote.  # noqa: E501

        The date the credit note is issued YYYY-MM-DD. If the Date element is not specified then it will default to the current date based on the timezone setting of the organisation  # noqa: E501

        :return: The date of this CreditNote.  # noqa: E501
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this CreditNote.

        The date the credit note is issued YYYY-MM-DD. If the Date element is not specified then it will default to the current date based on the timezone setting of the organisation  # noqa: E501

        :param date: The date of this CreditNote.  # noqa: E501
        :type: date
        """

        self._date = date

    @property
    def due_date(self):
        """Gets the due_date of this CreditNote.  # noqa: E501

        Date invoice is due – YYYY-MM-DD  # noqa: E501

        :return: The due_date of this CreditNote.  # noqa: E501
        :rtype: date
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this CreditNote.

        Date invoice is due – YYYY-MM-DD  # noqa: E501

        :param due_date: The due_date of this CreditNote.  # noqa: E501
        :type: date
        """

        self._due_date = due_date

    @property
    def status(self):
        """Gets the status of this CreditNote.  # noqa: E501

        See Credit Note Status Codes  # noqa: E501

        :return: The status of this CreditNote.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CreditNote.

        See Credit Note Status Codes  # noqa: E501

        :param status: The status of this CreditNote.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "DRAFT",
            "SUBMITTED",
            "DELETED",
            "AUTHORISED",
            "PAID",
            "VOIDED",
            "None",
        ]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def line_amount_types(self):
        """Gets the line_amount_types of this CreditNote.  # noqa: E501


        :return: The line_amount_types of this CreditNote.  # noqa: E501
        :rtype: LineAmountTypes
        """
        return self._line_amount_types

    @line_amount_types.setter
    def line_amount_types(self, line_amount_types):
        """Sets the line_amount_types of this CreditNote.


        :param line_amount_types: The line_amount_types of this CreditNote.  # noqa: E501
        :type: LineAmountTypes
        """

        self._line_amount_types = line_amount_types

    @property
    def line_items(self):
        """Gets the line_items of this CreditNote.  # noqa: E501

        See Invoice Line Items  # noqa: E501

        :return: The line_items of this CreditNote.  # noqa: E501
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this CreditNote.

        See Invoice Line Items  # noqa: E501

        :param line_items: The line_items of this CreditNote.  # noqa: E501
        :type: list[LineItem]
        """

        self._line_items = line_items

    @property
    def sub_total(self):
        """Gets the sub_total of this CreditNote.  # noqa: E501

        The subtotal of the credit note excluding taxes  # noqa: E501

        :return: The sub_total of this CreditNote.  # noqa: E501
        :rtype: float
        """
        return self._sub_total

    @sub_total.setter
    def sub_total(self, sub_total):
        """Sets the sub_total of this CreditNote.

        The subtotal of the credit note excluding taxes  # noqa: E501

        :param sub_total: The sub_total of this CreditNote.  # noqa: E501
        :type: float
        """

        self._sub_total = sub_total

    @property
    def total_tax(self):
        """Gets the total_tax of this CreditNote.  # noqa: E501

        The total tax on the credit note  # noqa: E501

        :return: The total_tax of this CreditNote.  # noqa: E501
        :rtype: float
        """
        return self._total_tax

    @total_tax.setter
    def total_tax(self, total_tax):
        """Sets the total_tax of this CreditNote.

        The total tax on the credit note  # noqa: E501

        :param total_tax: The total_tax of this CreditNote.  # noqa: E501
        :type: float
        """

        self._total_tax = total_tax

    @property
    def total(self):
        """Gets the total of this CreditNote.  # noqa: E501

        The total of the Credit Note(subtotal + total tax)  # noqa: E501

        :return: The total of this CreditNote.  # noqa: E501
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this CreditNote.

        The total of the Credit Note(subtotal + total tax)  # noqa: E501

        :param total: The total of this CreditNote.  # noqa: E501
        :type: float
        """

        self._total = total

    @property
    def cis_deduction(self):
        """Gets the cis_deduction of this CreditNote.  # noqa: E501

        CIS deduction for UK contractors  # noqa: E501

        :return: The cis_deduction of this CreditNote.  # noqa: E501
        :rtype: float
        """
        return self._cis_deduction

    @cis_deduction.setter
    def cis_deduction(self, cis_deduction):
        """Sets the cis_deduction of this CreditNote.

        CIS deduction for UK contractors  # noqa: E501

        :param cis_deduction: The cis_deduction of this CreditNote.  # noqa: E501
        :type: float
        """

        self._cis_deduction = cis_deduction

    @property
    def cis_rate(self):
        """Gets the cis_rate of this CreditNote.  # noqa: E501

        CIS Deduction rate for the organisation  # noqa: E501

        :return: The cis_rate of this CreditNote.  # noqa: E501
        :rtype: float
        """
        return self._cis_rate

    @cis_rate.setter
    def cis_rate(self, cis_rate):
        """Sets the cis_rate of this CreditNote.

        CIS Deduction rate for the organisation  # noqa: E501

        :param cis_rate: The cis_rate of this CreditNote.  # noqa: E501
        :type: float
        """

        self._cis_rate = cis_rate

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this CreditNote.  # noqa: E501

        UTC timestamp of last update to the credit note  # noqa: E501

        :return: The updated_date_utc of this CreditNote.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this CreditNote.

        UTC timestamp of last update to the credit note  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this CreditNote.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def currency_code(self):
        """Gets the currency_code of this CreditNote.  # noqa: E501


        :return: The currency_code of this CreditNote.  # noqa: E501
        :rtype: CurrencyCode
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this CreditNote.


        :param currency_code: The currency_code of this CreditNote.  # noqa: E501
        :type: CurrencyCode
        """

        self._currency_code = currency_code

    @property
    def fully_paid_on_date(self):
        """Gets the fully_paid_on_date of this CreditNote.  # noqa: E501

        Date when credit note was fully paid(UTC format)  # noqa: E501

        :return: The fully_paid_on_date of this CreditNote.  # noqa: E501
        :rtype: date
        """
        return self._fully_paid_on_date

    @fully_paid_on_date.setter
    def fully_paid_on_date(self, fully_paid_on_date):
        """Sets the fully_paid_on_date of this CreditNote.

        Date when credit note was fully paid(UTC format)  # noqa: E501

        :param fully_paid_on_date: The fully_paid_on_date of this CreditNote.  # noqa: E501
        :type: date
        """

        self._fully_paid_on_date = fully_paid_on_date

    @property
    def credit_note_id(self):
        """Gets the credit_note_id of this CreditNote.  # noqa: E501

        Xero generated unique identifier  # noqa: E501

        :return: The credit_note_id of this CreditNote.  # noqa: E501
        :rtype: str
        """
        return self._credit_note_id

    @credit_note_id.setter
    def credit_note_id(self, credit_note_id):
        """Sets the credit_note_id of this CreditNote.

        Xero generated unique identifier  # noqa: E501

        :param credit_note_id: The credit_note_id of this CreditNote.  # noqa: E501
        :type: str
        """

        self._credit_note_id = credit_note_id

    @property
    def credit_note_number(self):
        """Gets the credit_note_number of this CreditNote.  # noqa: E501

        ACCRECCREDIT – Unique alpha numeric code identifying credit note (when missing will auto-generate from your Organisation Invoice Settings)  # noqa: E501

        :return: The credit_note_number of this CreditNote.  # noqa: E501
        :rtype: str
        """
        return self._credit_note_number

    @credit_note_number.setter
    def credit_note_number(self, credit_note_number):
        """Sets the credit_note_number of this CreditNote.

        ACCRECCREDIT – Unique alpha numeric code identifying credit note (when missing will auto-generate from your Organisation Invoice Settings)  # noqa: E501

        :param credit_note_number: The credit_note_number of this CreditNote.  # noqa: E501
        :type: str
        """

        self._credit_note_number = credit_note_number

    @property
    def reference(self):
        """Gets the reference of this CreditNote.  # noqa: E501

        ACCRECCREDIT only – additional reference number  # noqa: E501

        :return: The reference of this CreditNote.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this CreditNote.

        ACCRECCREDIT only – additional reference number  # noqa: E501

        :param reference: The reference of this CreditNote.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def sent_to_contact(self):
        """Gets the sent_to_contact of this CreditNote.  # noqa: E501

        boolean to indicate if a credit note has been sent to a contact via  the Xero app (currently read only)  # noqa: E501

        :return: The sent_to_contact of this CreditNote.  # noqa: E501
        :rtype: bool
        """
        return self._sent_to_contact

    @sent_to_contact.setter
    def sent_to_contact(self, sent_to_contact):
        """Sets the sent_to_contact of this CreditNote.

        boolean to indicate if a credit note has been sent to a contact via  the Xero app (currently read only)  # noqa: E501

        :param sent_to_contact: The sent_to_contact of this CreditNote.  # noqa: E501
        :type: bool
        """

        self._sent_to_contact = sent_to_contact

    @property
    def currency_rate(self):
        """Gets the currency_rate of this CreditNote.  # noqa: E501

        The currency rate for a multicurrency invoice. If no rate is specified, the XE.com day rate is used  # noqa: E501

        :return: The currency_rate of this CreditNote.  # noqa: E501
        :rtype: float
        """
        return self._currency_rate

    @currency_rate.setter
    def currency_rate(self, currency_rate):
        """Sets the currency_rate of this CreditNote.

        The currency rate for a multicurrency invoice. If no rate is specified, the XE.com day rate is used  # noqa: E501

        :param currency_rate: The currency_rate of this CreditNote.  # noqa: E501
        :type: float
        """

        self._currency_rate = currency_rate

    @property
    def remaining_credit(self):
        """Gets the remaining_credit of this CreditNote.  # noqa: E501

        The remaining credit balance on the Credit Note  # noqa: E501

        :return: The remaining_credit of this CreditNote.  # noqa: E501
        :rtype: float
        """
        return self._remaining_credit

    @remaining_credit.setter
    def remaining_credit(self, remaining_credit):
        """Sets the remaining_credit of this CreditNote.

        The remaining credit balance on the Credit Note  # noqa: E501

        :param remaining_credit: The remaining_credit of this CreditNote.  # noqa: E501
        :type: float
        """

        self._remaining_credit = remaining_credit

    @property
    def allocations(self):
        """Gets the allocations of this CreditNote.  # noqa: E501

        See Allocations  # noqa: E501

        :return: The allocations of this CreditNote.  # noqa: E501
        :rtype: list[Allocation]
        """
        return self._allocations

    @allocations.setter
    def allocations(self, allocations):
        """Sets the allocations of this CreditNote.

        See Allocations  # noqa: E501

        :param allocations: The allocations of this CreditNote.  # noqa: E501
        :type: list[Allocation]
        """

        self._allocations = allocations

    @property
    def applied_amount(self):
        """Gets the applied_amount of this CreditNote.  # noqa: E501

        The amount of applied to an invoice  # noqa: E501

        :return: The applied_amount of this CreditNote.  # noqa: E501
        :rtype: float
        """
        return self._applied_amount

    @applied_amount.setter
    def applied_amount(self, applied_amount):
        """Sets the applied_amount of this CreditNote.

        The amount of applied to an invoice  # noqa: E501

        :param applied_amount: The applied_amount of this CreditNote.  # noqa: E501
        :type: float
        """

        self._applied_amount = applied_amount

    @property
    def payments(self):
        """Gets the payments of this CreditNote.  # noqa: E501

        See Payments  # noqa: E501

        :return: The payments of this CreditNote.  # noqa: E501
        :rtype: list[Payment]
        """
        return self._payments

    @payments.setter
    def payments(self, payments):
        """Sets the payments of this CreditNote.

        See Payments  # noqa: E501

        :param payments: The payments of this CreditNote.  # noqa: E501
        :type: list[Payment]
        """

        self._payments = payments

    @property
    def branding_theme_id(self):
        """Gets the branding_theme_id of this CreditNote.  # noqa: E501

        See BrandingThemes  # noqa: E501

        :return: The branding_theme_id of this CreditNote.  # noqa: E501
        :rtype: str
        """
        return self._branding_theme_id

    @branding_theme_id.setter
    def branding_theme_id(self, branding_theme_id):
        """Sets the branding_theme_id of this CreditNote.

        See BrandingThemes  # noqa: E501

        :param branding_theme_id: The branding_theme_id of this CreditNote.  # noqa: E501
        :type: str
        """

        self._branding_theme_id = branding_theme_id

    @property
    def status_attribute_string(self):
        """Gets the status_attribute_string of this CreditNote.  # noqa: E501

        A string to indicate if a invoice status  # noqa: E501

        :return: The status_attribute_string of this CreditNote.  # noqa: E501
        :rtype: str
        """
        return self._status_attribute_string

    @status_attribute_string.setter
    def status_attribute_string(self, status_attribute_string):
        """Sets the status_attribute_string of this CreditNote.

        A string to indicate if a invoice status  # noqa: E501

        :param status_attribute_string: The status_attribute_string of this CreditNote.  # noqa: E501
        :type: str
        """

        self._status_attribute_string = status_attribute_string

    @property
    def has_attachments(self):
        """Gets the has_attachments of this CreditNote.  # noqa: E501

        boolean to indicate if a credit note has an attachment  # noqa: E501

        :return: The has_attachments of this CreditNote.  # noqa: E501
        :rtype: bool
        """
        return self._has_attachments

    @has_attachments.setter
    def has_attachments(self, has_attachments):
        """Sets the has_attachments of this CreditNote.

        boolean to indicate if a credit note has an attachment  # noqa: E501

        :param has_attachments: The has_attachments of this CreditNote.  # noqa: E501
        :type: bool
        """

        self._has_attachments = has_attachments

    @property
    def has_errors(self):
        """Gets the has_errors of this CreditNote.  # noqa: E501

        A boolean to indicate if a credit note has an validation errors  # noqa: E501

        :return: The has_errors of this CreditNote.  # noqa: E501
        :rtype: bool
        """
        return self._has_errors

    @has_errors.setter
    def has_errors(self, has_errors):
        """Sets the has_errors of this CreditNote.

        A boolean to indicate if a credit note has an validation errors  # noqa: E501

        :param has_errors: The has_errors of this CreditNote.  # noqa: E501
        :type: bool
        """

        self._has_errors = has_errors

    @property
    def validation_errors(self):
        """Gets the validation_errors of this CreditNote.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this CreditNote.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this CreditNote.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this CreditNote.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors

    @property
    def warnings(self):
        """Gets the warnings of this CreditNote.  # noqa: E501

        Displays array of warning messages from the API  # noqa: E501

        :return: The warnings of this CreditNote.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this CreditNote.

        Displays array of warning messages from the API  # noqa: E501

        :param warnings: The warnings of this CreditNote.  # noqa: E501
        :type: list[ValidationError]
        """

        self._warnings = warnings



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Account(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"account_id": "str", "type": "str", "code": "str", "name": "str"}

    attribute_map = {
        "account_id": "accountID",
        "type": "type",
        "code": "code",
        "name": "name",
    }

    def __init__(self, account_id=None, type=None, code=None, name=None):  # noqa: E501
        """Account - a model defined in OpenAPI"""  # noqa: E501

        self._account_id = None
        self._type = None
        self._code = None
        self._name = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if type is not None:
            self.type = type
        if code is not None:
            self.code = code
        if name is not None:
            self.name = name

    @property
    def account_id(self):
        """Gets the account_id of this Account.  # noqa: E501

        The Xero identifier for Settings.  # noqa: E501

        :return: The account_id of this Account.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Account.

        The Xero identifier for Settings.  # noqa: E501

        :param account_id: The account_id of this Account.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def type(self):
        """Gets the type of this Account.  # noqa: E501

        The assigned AccountType  # noqa: E501

        :return: The type of this Account.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Account.

        The assigned AccountType  # noqa: E501

        :param type: The type of this Account.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "BANK",
            "EMPLOYERSNIC",
            "NICLIABILITY",
            "PAYEECONTRIBUTION",
            "PAYELIABILITY",
            "WAGESPAYABLE",
            "WAGESEXPENSE",
            "None",
        ]  # noqa: E501

        if type:
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                        type, allowed_values
                    )
                )

        self._type = type

    @property
    def code(self):
        """Gets the code of this Account.  # noqa: E501

        A unique 3 digit number for each Account  # noqa: E501

        :return: The code of this Account.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Account.

        A unique 3 digit number for each Account  # noqa: E501

        :param code: The code of this Account.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def name(self):
        """Gets the name of this Account.  # noqa: E501

        Name of the Account.  # noqa: E501

        :return: The name of this Account.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Account.

        Name of the Account.  # noqa: E501

        :param name: The name of this Account.  # noqa: E501
        :type: str
        """

        self._name = name



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Actions(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"actions": "list[Action]"}

    attribute_map = {"actions": "Actions"}

    def __init__(self, actions=None):  # noqa: E501
        """Actions - a model defined in OpenAPI"""  # noqa: E501

        self._actions = None
        self.discriminator = None

        if actions is not None:
            self.actions = actions

    @property
    def actions(self):
        """Gets the actions of this Actions.  # noqa: E501


        :return: The actions of this Actions.  # noqa: E501
        :rtype: list[Action]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this Actions.


        :param actions: The actions of this Actions.  # noqa: E501
        :type: list[Action]
        """

        self._actions = actions



# coding: utf-8

# flake8: noqa
"""
    Xero Files API

    These endpoints are specific to Xero Files API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


# import models into model package
from xero_python.file.models.association import Association
from xero_python.file.models.file_object import FileObject
from xero_python.file.models.files import Files
from xero_python.file.models.folder import Folder
from xero_python.file.models.folders import Folders
from xero_python.file.models.object_group import ObjectGroup
from xero_python.file.models.object_type import ObjectType
from xero_python.file.models.upload_object import UploadObject
from xero_python.file.models.user import User



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TaxRate(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "name": "str",
        "tax_type": "str",
        "tax_components": "list[TaxComponent]",
        "status": "str",
        "report_tax_type": "str",
        "can_apply_to_assets": "bool",
        "can_apply_to_equity": "bool",
        "can_apply_to_expenses": "bool",
        "can_apply_to_liabilities": "bool",
        "can_apply_to_revenue": "bool",
        "display_tax_rate": "float",
        "effective_rate": "float",
    }

    attribute_map = {
        "name": "Name",
        "tax_type": "TaxType",
        "tax_components": "TaxComponents",
        "status": "Status",
        "report_tax_type": "ReportTaxType",
        "can_apply_to_assets": "CanApplyToAssets",
        "can_apply_to_equity": "CanApplyToEquity",
        "can_apply_to_expenses": "CanApplyToExpenses",
        "can_apply_to_liabilities": "CanApplyToLiabilities",
        "can_apply_to_revenue": "CanApplyToRevenue",
        "display_tax_rate": "DisplayTaxRate",
        "effective_rate": "EffectiveRate",
    }

    def __init__(
        self,
        name=None,
        tax_type=None,
        tax_components=None,
        status=None,
        report_tax_type=None,
        can_apply_to_assets=None,
        can_apply_to_equity=None,
        can_apply_to_expenses=None,
        can_apply_to_liabilities=None,
        can_apply_to_revenue=None,
        display_tax_rate=None,
        effective_rate=None,
    ):  # noqa: E501
        """TaxRate - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._tax_type = None
        self._tax_components = None
        self._status = None
        self._report_tax_type = None
        self._can_apply_to_assets = None
        self._can_apply_to_equity = None
        self._can_apply_to_expenses = None
        self._can_apply_to_liabilities = None
        self._can_apply_to_revenue = None
        self._display_tax_rate = None
        self._effective_rate = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if tax_type is not None:
            self.tax_type = tax_type
        if tax_components is not None:
            self.tax_components = tax_components
        if status is not None:
            self.status = status
        if report_tax_type is not None:
            self.report_tax_type = report_tax_type
        if can_apply_to_assets is not None:
            self.can_apply_to_assets = can_apply_to_assets
        if can_apply_to_equity is not None:
            self.can_apply_to_equity = can_apply_to_equity
        if can_apply_to_expenses is not None:
            self.can_apply_to_expenses = can_apply_to_expenses
        if can_apply_to_liabilities is not None:
            self.can_apply_to_liabilities = can_apply_to_liabilities
        if can_apply_to_revenue is not None:
            self.can_apply_to_revenue = can_apply_to_revenue
        if display_tax_rate is not None:
            self.display_tax_rate = display_tax_rate
        if effective_rate is not None:
            self.effective_rate = effective_rate

    @property
    def name(self):
        """Gets the name of this TaxRate.  # noqa: E501

        Name of tax rate  # noqa: E501

        :return: The name of this TaxRate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaxRate.

        Name of tax rate  # noqa: E501

        :param name: The name of this TaxRate.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def tax_type(self):
        """Gets the tax_type of this TaxRate.  # noqa: E501

        The tax type  # noqa: E501

        :return: The tax_type of this TaxRate.  # noqa: E501
        :rtype: str
        """
        return self._tax_type

    @tax_type.setter
    def tax_type(self, tax_type):
        """Sets the tax_type of this TaxRate.

        The tax type  # noqa: E501

        :param tax_type: The tax_type of this TaxRate.  # noqa: E501
        :type: str
        """

        self._tax_type = tax_type

    @property
    def tax_components(self):
        """Gets the tax_components of this TaxRate.  # noqa: E501

        See TaxComponents  # noqa: E501

        :return: The tax_components of this TaxRate.  # noqa: E501
        :rtype: list[TaxComponent]
        """
        return self._tax_components

    @tax_components.setter
    def tax_components(self, tax_components):
        """Sets the tax_components of this TaxRate.

        See TaxComponents  # noqa: E501

        :param tax_components: The tax_components of this TaxRate.  # noqa: E501
        :type: list[TaxComponent]
        """

        self._tax_components = tax_components

    @property
    def status(self):
        """Gets the status of this TaxRate.  # noqa: E501

        See Status Codes  # noqa: E501

        :return: The status of this TaxRate.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TaxRate.

        See Status Codes  # noqa: E501

        :param status: The status of this TaxRate.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "ACTIVE",
            "DELETED",
            "ARCHIVED",
            "PENDING",
            "None",
        ]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def report_tax_type(self):
        """Gets the report_tax_type of this TaxRate.  # noqa: E501

        See ReportTaxTypes  # noqa: E501

        :return: The report_tax_type of this TaxRate.  # noqa: E501
        :rtype: str
        """
        return self._report_tax_type

    @report_tax_type.setter
    def report_tax_type(self, report_tax_type):
        """Sets the report_tax_type of this TaxRate.

        See ReportTaxTypes  # noqa: E501

        :param report_tax_type: The report_tax_type of this TaxRate.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "AVALARA",
            "BASEXCLUDED",
            "CAPITALSALESOUTPUT",
            "CAPITALEXPENSESINPUT",
            "ECOUTPUT",
            "ECOUTPUTSERVICES",
            "ECINPUT",
            "ECACQUISITIONS",
            "EXEMPTEXPENSES",
            "EXEMPTINPUT",
            "EXEMPTOUTPUT",
            "GSTONIMPORTS",
            "INPUT",
            "INPUTTAXED",
            "MOSSSALES",
            "NONE",
            "NONEOUTPUT",
            "OUTPUT",
            "PURCHASESINPUT",
            "SALESOUTPUT",
            "EXEMPTCAPITAL",
            "EXEMPTEXPORT",
            "CAPITALEXINPUT",
            "GSTONCAPIMPORTS",
            "GSTONCAPITALIMPORTS",
            "REVERSECHARGES",
            "PAYMENTS",
            "INVOICE",
            "CASH",
            "ACCRUAL",
            "FLATRATECASH",
            "FLATRATEACCRUAL",
            "ACCRUALS",
            "TXCA",
            "SRCAS",
            "DSOUTPUT",
            "BLINPUT2",
            "EPINPUT",
            "IMINPUT2",
            "MEINPUT",
            "IGDSINPUT2",
            "ESN33OUTPUT",
            "OPINPUT",
            "OSOUTPUT",
            "TXN33INPUT",
            "TXESSINPUT",
            "TXREINPUT",
            "TXPETINPUT",
            "NRINPUT",
            "ES33OUTPUT",
            "ZERORATEDINPUT",
            "ZERORATEDOUTPUT",
            "DRCHARGESUPPLY",
            "DRCHARGE",
            "CAPINPUT",
            "CAPIMPORTS",
            "IMINPUT",
            "INPUT2",
            "CIUINPUT",
            "SRINPUT",
            "OUTPUT2",
            "SROUTPUT",
            "CAPOUTPUT",
            "SROUTPUT2",
            "CIUOUTPUT",
            "ZROUTPUT",
            "ZREXPORT",
            "ACC28PLUS",
            "ACCUPTO28",
            "OTHEROUTPUT",
            "SHOUTPUT",
            "ZRINPUT",
            "BADDEBT",
            "OTHERINPUT",
            "None",
        ]  # noqa: E501

        if report_tax_type:
            if report_tax_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `report_tax_type` ({0}), must be one of {1}".format(  # noqa: E501
                        report_tax_type, allowed_values
                    )
                )

        self._report_tax_type = report_tax_type

    @property
    def can_apply_to_assets(self):
        """Gets the can_apply_to_assets of this TaxRate.  # noqa: E501

        Boolean to describe if tax rate can be used for asset accounts i.e.  true,false  # noqa: E501

        :return: The can_apply_to_assets of this TaxRate.  # noqa: E501
        :rtype: bool
        """
        return self._can_apply_to_assets

    @can_apply_to_assets.setter
    def can_apply_to_assets(self, can_apply_to_assets):
        """Sets the can_apply_to_assets of this TaxRate.

        Boolean to describe if tax rate can be used for asset accounts i.e.  true,false  # noqa: E501

        :param can_apply_to_assets: The can_apply_to_assets of this TaxRate.  # noqa: E501
        :type: bool
        """

        self._can_apply_to_assets = can_apply_to_assets

    @property
    def can_apply_to_equity(self):
        """Gets the can_apply_to_equity of this TaxRate.  # noqa: E501

        Boolean to describe if tax rate can be used for equity accounts i.e true,false  # noqa: E501

        :return: The can_apply_to_equity of this TaxRate.  # noqa: E501
        :rtype: bool
        """
        return self._can_apply_to_equity

    @can_apply_to_equity.setter
    def can_apply_to_equity(self, can_apply_to_equity):
        """Sets the can_apply_to_equity of this TaxRate.

        Boolean to describe if tax rate can be used for equity accounts i.e true,false  # noqa: E501

        :param can_apply_to_equity: The can_apply_to_equity of this TaxRate.  # noqa: E501
        :type: bool
        """

        self._can_apply_to_equity = can_apply_to_equity

    @property
    def can_apply_to_expenses(self):
        """Gets the can_apply_to_expenses of this TaxRate.  # noqa: E501

        Boolean to describe if tax rate can be used for expense accounts  i.e. true,false  # noqa: E501

        :return: The can_apply_to_expenses of this TaxRate.  # noqa: E501
        :rtype: bool
        """
        return self._can_apply_to_expenses

    @can_apply_to_expenses.setter
    def can_apply_to_expenses(self, can_apply_to_expenses):
        """Sets the can_apply_to_expenses of this TaxRate.

        Boolean to describe if tax rate can be used for expense accounts  i.e. true,false  # noqa: E501

        :param can_apply_to_expenses: The can_apply_to_expenses of this TaxRate.  # noqa: E501
        :type: bool
        """

        self._can_apply_to_expenses = can_apply_to_expenses

    @property
    def can_apply_to_liabilities(self):
        """Gets the can_apply_to_liabilities of this TaxRate.  # noqa: E501

        Boolean to describe if tax rate can be used for liability accounts  i.e. true,false  # noqa: E501

        :return: The can_apply_to_liabilities of this TaxRate.  # noqa: E501
        :rtype: bool
        """
        return self._can_apply_to_liabilities

    @can_apply_to_liabilities.setter
    def can_apply_to_liabilities(self, can_apply_to_liabilities):
        """Sets the can_apply_to_liabilities of this TaxRate.

        Boolean to describe if tax rate can be used for liability accounts  i.e. true,false  # noqa: E501

        :param can_apply_to_liabilities: The can_apply_to_liabilities of this TaxRate.  # noqa: E501
        :type: bool
        """

        self._can_apply_to_liabilities = can_apply_to_liabilities

    @property
    def can_apply_to_revenue(self):
        """Gets the can_apply_to_revenue of this TaxRate.  # noqa: E501

        Boolean to describe if tax rate can be used for revenue accounts i.e. true,false  # noqa: E501

        :return: The can_apply_to_revenue of this TaxRate.  # noqa: E501
        :rtype: bool
        """
        return self._can_apply_to_revenue

    @can_apply_to_revenue.setter
    def can_apply_to_revenue(self, can_apply_to_revenue):
        """Sets the can_apply_to_revenue of this TaxRate.

        Boolean to describe if tax rate can be used for revenue accounts i.e. true,false  # noqa: E501

        :param can_apply_to_revenue: The can_apply_to_revenue of this TaxRate.  # noqa: E501
        :type: bool
        """

        self._can_apply_to_revenue = can_apply_to_revenue

    @property
    def display_tax_rate(self):
        """Gets the display_tax_rate of this TaxRate.  # noqa: E501

        Tax Rate (decimal to 4dp) e.g 12.5000  # noqa: E501

        :return: The display_tax_rate of this TaxRate.  # noqa: E501
        :rtype: float
        """
        return self._display_tax_rate

    @display_tax_rate.setter
    def display_tax_rate(self, display_tax_rate):
        """Sets the display_tax_rate of this TaxRate.

        Tax Rate (decimal to 4dp) e.g 12.5000  # noqa: E501

        :param display_tax_rate: The display_tax_rate of this TaxRate.  # noqa: E501
        :type: float
        """

        self._display_tax_rate = display_tax_rate

    @property
    def effective_rate(self):
        """Gets the effective_rate of this TaxRate.  # noqa: E501

        Effective Tax Rate (decimal to 4dp) e.g 12.5000  # noqa: E501

        :return: The effective_rate of this TaxRate.  # noqa: E501
        :rtype: float
        """
        return self._effective_rate

    @effective_rate.setter
    def effective_rate(self, effective_rate):
        """Sets the effective_rate of this TaxRate.

        Effective Tax Rate (decimal to 4dp) e.g 12.5000  # noqa: E501

        :param effective_rate: The effective_rate of this TaxRate.  # noqa: E501
        :type: float
        """

        self._effective_rate = effective_rate



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class EmployeePayTemplate(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "employee_id": "str",
        "earning_templates": "list[EarningsTemplate]",
    }

    attribute_map = {
        "employee_id": "employeeID",
        "earning_templates": "earningTemplates",
    }

    def __init__(self, employee_id=None, earning_templates=None):  # noqa: E501
        """EmployeePayTemplate - a model defined in OpenAPI"""  # noqa: E501

        self._employee_id = None
        self._earning_templates = None
        self.discriminator = None

        if employee_id is not None:
            self.employee_id = employee_id
        if earning_templates is not None:
            self.earning_templates = earning_templates

    @property
    def employee_id(self):
        """Gets the employee_id of this EmployeePayTemplate.  # noqa: E501

        Unique identifier for the employee  # noqa: E501

        :return: The employee_id of this EmployeePayTemplate.  # noqa: E501
        :rtype: str
        """
        return self._employee_id

    @employee_id.setter
    def employee_id(self, employee_id):
        """Sets the employee_id of this EmployeePayTemplate.

        Unique identifier for the employee  # noqa: E501

        :param employee_id: The employee_id of this EmployeePayTemplate.  # noqa: E501
        :type: str
        """

        self._employee_id = employee_id

    @property
    def earning_templates(self):
        """Gets the earning_templates of this EmployeePayTemplate.  # noqa: E501


        :return: The earning_templates of this EmployeePayTemplate.  # noqa: E501
        :rtype: list[EarningsTemplate]
        """
        return self._earning_templates

    @earning_templates.setter
    def earning_templates(self, earning_templates):
        """Sets the earning_templates of this EmployeePayTemplate.


        :param earning_templates: The earning_templates of this EmployeePayTemplate.  # noqa: E501
        :type: list[EarningsTemplate]
        """

        self._earning_templates = earning_templates



# coding: utf-8

"""
    Xero Projects API

    This is the Xero Projects API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Amount(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"currency": "CurrencyCode", "value": "float"}

    attribute_map = {"currency": "currency", "value": "value"}

    def __init__(self, currency=None, value=None):  # noqa: E501
        """Amount - a model defined in OpenAPI"""  # noqa: E501

        self._currency = None
        self._value = None
        self.discriminator = None

        if currency is not None:
            self.currency = currency
        if value is not None:
            self.value = value

    @property
    def currency(self):
        """Gets the currency of this Amount.  # noqa: E501


        :return: The currency of this Amount.  # noqa: E501
        :rtype: CurrencyCode
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Amount.


        :param currency: The currency of this Amount.  # noqa: E501
        :type: CurrencyCode
        """

        self._currency = currency

    @property
    def value(self):
        """Gets the value of this Amount.  # noqa: E501


        :return: The value of this Amount.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Amount.


        :param value: The value of this Amount.  # noqa: E501
        :type: float
        """

        self._value = value



# coding: utf-8

"""
    Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 2.2.7
    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TenNinteyNineContact(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "box1": "float",
        "box2": "float",
        "box3": "float",
        "box4": "float",
        "box5": "float",
        "box6": "float",
        "box7": "float",
        "box8": "float",
        "box9": "float",
        "box10": "float",
        "box11": "float",
        "box13": "float",
        "box14": "float",
        "name": "str",
        "federal_tax_id_type": "str",
        "city": "str",
        "zip": "str",
        "state": "str",
        "email": "str",
        "street_address": "str",
        "tax_id": "str",
        "contact_id": "str",
    }

    attribute_map = {
        "box1": "Box1",
        "box2": "Box2",
        "box3": "Box3",
        "box4": "Box4",
        "box5": "Box5",
        "box6": "Box6",
        "box7": "Box7",
        "box8": "Box8",
        "box9": "Box9",
        "box10": "Box10",
        "box11": "Box11",
        "box13": "Box13",
        "box14": "Box14",
        "name": "Name",
        "federal_tax_id_type": "FederalTaxIDType",
        "city": "City",
        "zip": "Zip",
        "state": "State",
        "email": "Email",
        "street_address": "StreetAddress",
        "tax_id": "TaxID",
        "contact_id": "ContactId",
    }

    def __init__(
        self,
        box1=None,
        box2=None,
        box3=None,
        box4=None,
        box5=None,
        box6=None,
        box7=None,
        box8=None,
        box9=None,
        box10=None,
        box11=None,
        box13=None,
        box14=None,
        name=None,
        federal_tax_id_type=None,
        city=None,
        zip=None,
        state=None,
        email=None,
        street_address=None,
        tax_id=None,
        contact_id=None,
    ):  # noqa: E501
        """TenNinteyNineContact - a model defined in OpenAPI"""  # noqa: E501

        self._box1 = None
        self._box2 = None
        self._box3 = None
        self._box4 = None
        self._box5 = None
        self._box6 = None
        self._box7 = None
        self._box8 = None
        self._box9 = None
        self._box10 = None
        self._box11 = None
        self._box13 = None
        self._box14 = None
        self._name = None
        self._federal_tax_id_type = None
        self._city = None
        self._zip = None
        self._state = None
        self._email = None
        self._street_address = None
        self._tax_id = None
        self._contact_id = None
        self.discriminator = None

        if box1 is not None:
            self.box1 = box1
        if box2 is not None:
            self.box2 = box2
        if box3 is not None:
            self.box3 = box3
        if box4 is not None:
            self.box4 = box4
        if box5 is not None:
            self.box5 = box5
        if box6 is not None:
            self.box6 = box6
        if box7 is not None:
            self.box7 = box7
        if box8 is not None:
            self.box8 = box8
        if box9 is not None:
            self.box9 = box9
        if box10 is not None:
            self.box10 = box10
        if box11 is not None:
            self.box11 = box11
        if box13 is not None:
            self.box13 = box13
        if box14 is not None:
            self.box14 = box14
        if name is not None:
            self.name = name
        if federal_tax_id_type is not None:
            self.federal_tax_id_type = federal_tax_id_type
        if city is not None:
            self.city = city
        if zip is not None:
            self.zip = zip
        if state is not None:
            self.state = state
        if email is not None:
            self.email = email
        if street_address is not None:
            self.street_address = street_address
        if tax_id is not None:
            self.tax_id = tax_id
        if contact_id is not None:
            self.contact_id = contact_id

    @property
    def box1(self):
        """Gets the box1 of this TenNinteyNineContact.  # noqa: E501

        Box 1 on 1099 Form  # noqa: E501

        :return: The box1 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box1

    @box1.setter
    def box1(self, box1):
        """Sets the box1 of this TenNinteyNineContact.

        Box 1 on 1099 Form  # noqa: E501

        :param box1: The box1 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box1 = box1

    @property
    def box2(self):
        """Gets the box2 of this TenNinteyNineContact.  # noqa: E501

        Box 2 on 1099 Form  # noqa: E501

        :return: The box2 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box2

    @box2.setter
    def box2(self, box2):
        """Sets the box2 of this TenNinteyNineContact.

        Box 2 on 1099 Form  # noqa: E501

        :param box2: The box2 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box2 = box2

    @property
    def box3(self):
        """Gets the box3 of this TenNinteyNineContact.  # noqa: E501

        Box 3 on 1099 Form  # noqa: E501

        :return: The box3 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box3

    @box3.setter
    def box3(self, box3):
        """Sets the box3 of this TenNinteyNineContact.

        Box 3 on 1099 Form  # noqa: E501

        :param box3: The box3 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box3 = box3

    @property
    def box4(self):
        """Gets the box4 of this TenNinteyNineContact.  # noqa: E501

        Box 4 on 1099 Form  # noqa: E501

        :return: The box4 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box4

    @box4.setter
    def box4(self, box4):
        """Sets the box4 of this TenNinteyNineContact.

        Box 4 on 1099 Form  # noqa: E501

        :param box4: The box4 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box4 = box4

    @property
    def box5(self):
        """Gets the box5 of this TenNinteyNineContact.  # noqa: E501

        Box 5 on 1099 Form  # noqa: E501

        :return: The box5 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box5

    @box5.setter
    def box5(self, box5):
        """Sets the box5 of this TenNinteyNineContact.

        Box 5 on 1099 Form  # noqa: E501

        :param box5: The box5 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box5 = box5

    @property
    def box6(self):
        """Gets the box6 of this TenNinteyNineContact.  # noqa: E501

        Box 6 on 1099 Form  # noqa: E501

        :return: The box6 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box6

    @box6.setter
    def box6(self, box6):
        """Sets the box6 of this TenNinteyNineContact.

        Box 6 on 1099 Form  # noqa: E501

        :param box6: The box6 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box6 = box6

    @property
    def box7(self):
        """Gets the box7 of this TenNinteyNineContact.  # noqa: E501

        Box 7 on 1099 Form  # noqa: E501

        :return: The box7 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box7

    @box7.setter
    def box7(self, box7):
        """Sets the box7 of this TenNinteyNineContact.

        Box 7 on 1099 Form  # noqa: E501

        :param box7: The box7 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box7 = box7

    @property
    def box8(self):
        """Gets the box8 of this TenNinteyNineContact.  # noqa: E501

        Box 8 on 1099 Form  # noqa: E501

        :return: The box8 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box8

    @box8.setter
    def box8(self, box8):
        """Sets the box8 of this TenNinteyNineContact.

        Box 8 on 1099 Form  # noqa: E501

        :param box8: The box8 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box8 = box8

    @property
    def box9(self):
        """Gets the box9 of this TenNinteyNineContact.  # noqa: E501

        Box 9 on 1099 Form  # noqa: E501

        :return: The box9 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box9

    @box9.setter
    def box9(self, box9):
        """Sets the box9 of this TenNinteyNineContact.

        Box 9 on 1099 Form  # noqa: E501

        :param box9: The box9 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box9 = box9

    @property
    def box10(self):
        """Gets the box10 of this TenNinteyNineContact.  # noqa: E501

        Box 10 on 1099 Form  # noqa: E501

        :return: The box10 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box10

    @box10.setter
    def box10(self, box10):
        """Sets the box10 of this TenNinteyNineContact.

        Box 10 on 1099 Form  # noqa: E501

        :param box10: The box10 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box10 = box10

    @property
    def box11(self):
        """Gets the box11 of this TenNinteyNineContact.  # noqa: E501

        Box 11 on 1099 Form  # noqa: E501

        :return: The box11 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box11

    @box11.setter
    def box11(self, box11):
        """Sets the box11 of this TenNinteyNineContact.

        Box 11 on 1099 Form  # noqa: E501

        :param box11: The box11 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box11 = box11

    @property
    def box13(self):
        """Gets the box13 of this TenNinteyNineContact.  # noqa: E501

        Box 13 on 1099 Form  # noqa: E501

        :return: The box13 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box13

    @box13.setter
    def box13(self, box13):
        """Sets the box13 of this TenNinteyNineContact.

        Box 13 on 1099 Form  # noqa: E501

        :param box13: The box13 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box13 = box13

    @property
    def box14(self):
        """Gets the box14 of this TenNinteyNineContact.  # noqa: E501

        Box 14 on 1099 Form  # noqa: E501

        :return: The box14 of this TenNinteyNineContact.  # noqa: E501
        :rtype: float
        """
        return self._box14

    @box14.setter
    def box14(self, box14):
        """Sets the box14 of this TenNinteyNineContact.

        Box 14 on 1099 Form  # noqa: E501

        :param box14: The box14 of this TenNinteyNineContact.  # noqa: E501
        :type: float
        """

        self._box14 = box14

    @property
    def name(self):
        """Gets the name of this TenNinteyNineContact.  # noqa: E501

        Contact name on 1099 Form  # noqa: E501

        :return: The name of this TenNinteyNineContact.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TenNinteyNineContact.

        Contact name on 1099 Form  # noqa: E501

        :param name: The name of this TenNinteyNineContact.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def federal_tax_id_type(self):
        """Gets the federal_tax_id_type of this TenNinteyNineContact.  # noqa: E501

        Contact Fed Tax ID type  # noqa: E501

        :return: The federal_tax_id_type of this TenNinteyNineContact.  # noqa: E501
        :rtype: str
        """
        return self._federal_tax_id_type

    @federal_tax_id_type.setter
    def federal_tax_id_type(self, federal_tax_id_type):
        """Sets the federal_tax_id_type of this TenNinteyNineContact.

        Contact Fed Tax ID type  # noqa: E501

        :param federal_tax_id_type: The federal_tax_id_type of this TenNinteyNineContact.  # noqa: E501
        :type: str
        """

        self._federal_tax_id_type = federal_tax_id_type

    @property
    def city(self):
        """Gets the city of this TenNinteyNineContact.  # noqa: E501

        Contact city on 1099 Form  # noqa: E501

        :return: The city of this TenNinteyNineContact.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this TenNinteyNineContact.

        Contact city on 1099 Form  # noqa: E501

        :param city: The city of this TenNinteyNineContact.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def zip(self):
        """Gets the zip of this TenNinteyNineContact.  # noqa: E501

        Contact zip on 1099 Form  # noqa: E501

        :return: The zip of this TenNinteyNineContact.  # noqa: E501
        :rtype: str
        """
        return self._zip

    @zip.setter
    def zip(self, zip):
        """Sets the zip of this TenNinteyNineContact.

        Contact zip on 1099 Form  # noqa: E501

        :param zip: The zip of this TenNinteyNineContact.  # noqa: E501
        :type: str
        """

        self._zip = zip

    @property
    def state(self):
        """Gets the state of this TenNinteyNineContact.  # noqa: E501

        Contact State on 1099 Form  # noqa: E501

        :return: The state of this TenNinteyNineContact.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this TenNinteyNineContact.

        Contact State on 1099 Form  # noqa: E501

        :param state: The state of this TenNinteyNineContact.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def email(self):
        """Gets the email of this TenNinteyNineContact.  # noqa: E501

        Contact email on 1099 Form  # noqa: E501

        :return: The email of this TenNinteyNineContact.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this TenNinteyNineContact.

        Contact email on 1099 Form  # noqa: E501

        :param email: The email of this TenNinteyNineContact.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def street_address(self):
        """Gets the street_address of this TenNinteyNineContact.  # noqa: E501

        Contact address on 1099 Form  # noqa: E501

        :return: The street_address of this TenNinteyNineContact.  # noqa: E501
        :rtype: str
        """
        return self._street_address

    @street_address.setter
    def street_address(self, street_address):
        """Sets the street_address of this TenNinteyNineContact.

        Contact address on 1099 Form  # noqa: E501

        :param street_address: The street_address of this TenNinteyNineContact.  # noqa: E501
        :type: str
        """

        self._street_address = street_address

    @property
    def tax_id(self):
        """Gets the tax_id of this TenNinteyNineContact.  # noqa: E501

        Contact tax id on 1099 Form  # noqa: E501

        :return: The tax_id of this TenNinteyNineContact.  # noqa: E501
        :rtype: str
        """
        return self._tax_id

    @tax_id.setter
    def tax_id(self, tax_id):
        """Sets the tax_id of this TenNinteyNineContact.

        Contact tax id on 1099 Form  # noqa: E501

        :param tax_id: The tax_id of this TenNinteyNineContact.  # noqa: E501
        :type: str
        """

        self._tax_id = tax_id

    @property
    def contact_id(self):
        """Gets the contact_id of this TenNinteyNineContact.  # noqa: E501

        Contact contact id  # noqa: E501

        :return: The contact_id of this TenNinteyNineContact.  # noqa: E501
        :rtype: str
        """
        return self._contact_id

    @contact_id.setter
    def contact_id(self, contact_id):
        """Sets the contact_id of this TenNinteyNineContact.

        Contact contact id  # noqa: E501

        :param contact_id: The contact_id of this TenNinteyNineContact.  # noqa: E501
        :type: str
        """

        self._contact_id = contact_id



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class SuperFundProduct(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"abn": "str", "usi": "str", "spin": "str", "product_name": "str"}

    attribute_map = {
        "abn": "ABN",
        "usi": "USI",
        "spin": "SPIN",
        "product_name": "ProductName",
    }

    def __init__(self, abn=None, usi=None, spin=None, product_name=None):  # noqa: E501
        """SuperFundProduct - a model defined in OpenAPI"""  # noqa: E501

        self._abn = None
        self._usi = None
        self._spin = None
        self._product_name = None
        self.discriminator = None

        if abn is not None:
            self.abn = abn
        if usi is not None:
            self.usi = usi
        if spin is not None:
            self.spin = spin
        if product_name is not None:
            self.product_name = product_name

    @property
    def abn(self):
        """Gets the abn of this SuperFundProduct.  # noqa: E501

        The ABN of the Regulated SuperFund  # noqa: E501

        :return: The abn of this SuperFundProduct.  # noqa: E501
        :rtype: str
        """
        return self._abn

    @abn.setter
    def abn(self, abn):
        """Sets the abn of this SuperFundProduct.

        The ABN of the Regulated SuperFund  # noqa: E501

        :param abn: The abn of this SuperFundProduct.  # noqa: E501
        :type: str
        """

        self._abn = abn

    @property
    def usi(self):
        """Gets the usi of this SuperFundProduct.  # noqa: E501

        The USI of the Regulated SuperFund  # noqa: E501

        :return: The usi of this SuperFundProduct.  # noqa: E501
        :rtype: str
        """
        return self._usi

    @usi.setter
    def usi(self, usi):
        """Sets the usi of this SuperFundProduct.

        The USI of the Regulated SuperFund  # noqa: E501

        :param usi: The usi of this SuperFundProduct.  # noqa: E501
        :type: str
        """

        self._usi = usi

    @property
    def spin(self):
        """Gets the spin of this SuperFundProduct.  # noqa: E501

        The SPIN of the Regulated SuperFund. This field has been deprecated. New superfunds will not have a SPIN value. The USI field should be used instead of SPIN  # noqa: E501

        :return: The spin of this SuperFundProduct.  # noqa: E501
        :rtype: str
        """
        return self._spin

    @spin.setter
    def spin(self, spin):
        """Sets the spin of this SuperFundProduct.

        The SPIN of the Regulated SuperFund. This field has been deprecated. New superfunds will not have a SPIN value. The USI field should be used instead of SPIN  # noqa: E501

        :param spin: The spin of this SuperFundProduct.  # noqa: E501
        :type: str
        """

        self._spin = spin

    @property
    def product_name(self):
        """Gets the product_name of this SuperFundProduct.  # noqa: E501

        The name of the Regulated SuperFund  # noqa: E501

        :return: The product_name of this SuperFundProduct.  # noqa: E501
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """Sets the product_name of this SuperFundProduct.

        The name of the Regulated SuperFund  # noqa: E501

        :param product_name: The product_name of this SuperFundProduct.  # noqa: E501
        :type: str
        """

        self._product_name = product_name



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Report(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "report_id": "str",
        "report_name": "str",
        "report_type": "str",
        "report_title": "str",
        "report_date": "str",
        "updated_date_utc": "datetime[ms-format]",
        "contacts": "list[TenNinetyNineContact]",
    }

    attribute_map = {
        "report_id": "ReportID",
        "report_name": "ReportName",
        "report_type": "ReportType",
        "report_title": "ReportTitle",
        "report_date": "ReportDate",
        "updated_date_utc": "UpdatedDateUTC",
        "contacts": "Contacts",
    }

    def __init__(
        self,
        report_id=None,
        report_name=None,
        report_type=None,
        report_title=None,
        report_date=None,
        updated_date_utc=None,
        contacts=None,
    ):  # noqa: E501
        """Report - a model defined in OpenAPI"""  # noqa: E501

        self._report_id = None
        self._report_name = None
        self._report_type = None
        self._report_title = None
        self._report_date = None
        self._updated_date_utc = None
        self._contacts = None
        self.discriminator = None

        if report_id is not None:
            self.report_id = report_id
        if report_name is not None:
            self.report_name = report_name
        if report_type is not None:
            self.report_type = report_type
        if report_title is not None:
            self.report_title = report_title
        if report_date is not None:
            self.report_date = report_date
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if contacts is not None:
            self.contacts = contacts

    @property
    def report_id(self):
        """Gets the report_id of this Report.  # noqa: E501

        See Prepayment Types  # noqa: E501

        :return: The report_id of this Report.  # noqa: E501
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """Sets the report_id of this Report.

        See Prepayment Types  # noqa: E501

        :param report_id: The report_id of this Report.  # noqa: E501
        :type: str
        """

        self._report_id = report_id

    @property
    def report_name(self):
        """Gets the report_name of this Report.  # noqa: E501

        See Prepayment Types  # noqa: E501

        :return: The report_name of this Report.  # noqa: E501
        :rtype: str
        """
        return self._report_name

    @report_name.setter
    def report_name(self, report_name):
        """Sets the report_name of this Report.

        See Prepayment Types  # noqa: E501

        :param report_name: The report_name of this Report.  # noqa: E501
        :type: str
        """

        self._report_name = report_name

    @property
    def report_type(self):
        """Gets the report_type of this Report.  # noqa: E501

        See Prepayment Types  # noqa: E501

        :return: The report_type of this Report.  # noqa: E501
        :rtype: str
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """Sets the report_type of this Report.

        See Prepayment Types  # noqa: E501

        :param report_type: The report_type of this Report.  # noqa: E501
        :type: str
        """
        allowed_values = ["AgedPayablesByContact", "None"]  # noqa: E501

        if report_type:
            if report_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `report_type` ({0}), must be one of {1}".format(  # noqa: E501
                        report_type, allowed_values
                    )
                )

        self._report_type = report_type

    @property
    def report_title(self):
        """Gets the report_title of this Report.  # noqa: E501

        See Prepayment Types  # noqa: E501

        :return: The report_title of this Report.  # noqa: E501
        :rtype: str
        """
        return self._report_title

    @report_title.setter
    def report_title(self, report_title):
        """Sets the report_title of this Report.

        See Prepayment Types  # noqa: E501

        :param report_title: The report_title of this Report.  # noqa: E501
        :type: str
        """

        self._report_title = report_title

    @property
    def report_date(self):
        """Gets the report_date of this Report.  # noqa: E501

        Date of report  # noqa: E501

        :return: The report_date of this Report.  # noqa: E501
        :rtype: str
        """
        return self._report_date

    @report_date.setter
    def report_date(self, report_date):
        """Sets the report_date of this Report.

        Date of report  # noqa: E501

        :param report_date: The report_date of this Report.  # noqa: E501
        :type: str
        """

        self._report_date = report_date

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this Report.  # noqa: E501

        Updated Date  # noqa: E501

        :return: The updated_date_utc of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this Report.

        Updated Date  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this Report.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def contacts(self):
        """Gets the contacts of this Report.  # noqa: E501


        :return: The contacts of this Report.  # noqa: E501
        :rtype: list[TenNinetyNineContact]
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """Sets the contacts of this Report.


        :param contacts: The contacts of this Report.  # noqa: E501
        :type: list[TenNinetyNineContact]
        """

        self._contacts = contacts



# coding: utf-8

"""
    Xero Files API

    These endpoints are specific to Xero Files API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from enum import Enum


class ObjectGroup(Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    allowed enum values
    """

    ACCOUNT = "Account"
    BANKTRANSACTION = "BankTransaction"
    CONTACT = "Contact"
    CREDITNOTE = "CreditNote"
    INVOICE = "Invoice"
    ITEM = "Item"
    MANUALJOURNAL = "ManualJournal"
    OVERPAYMENT = "Overpayment"
    PAYMENT = "Payment"
    PREPAYMENT = "Prepayment"
    RECEIPT = "Receipt"



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TimesheetObject(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"timesheet": "Timesheet"}

    attribute_map = {"timesheet": "Timesheet"}

    def __init__(self, timesheet=None):  # noqa: E501
        """TimesheetObject - a model defined in OpenAPI"""  # noqa: E501

        self._timesheet = None
        self.discriminator = None

        if timesheet is not None:
            self.timesheet = timesheet

    @property
    def timesheet(self):
        """Gets the timesheet of this TimesheetObject.  # noqa: E501


        :return: The timesheet of this TimesheetObject.  # noqa: E501
        :rtype: Timesheet
        """
        return self._timesheet

    @timesheet.setter
    def timesheet(self, timesheet):
        """Sets the timesheet of this TimesheetObject.


        :param timesheet: The timesheet of this TimesheetObject.  # noqa: E501
        :type: Timesheet
        """

        self._timesheet = timesheet



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Address(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "address_type": "str",
        "address_line1": "str",
        "address_line2": "str",
        "address_line3": "str",
        "address_line4": "str",
        "city": "str",
        "region": "str",
        "postal_code": "str",
        "country": "str",
        "attention_to": "str",
    }

    attribute_map = {
        "address_type": "AddressType",
        "address_line1": "AddressLine1",
        "address_line2": "AddressLine2",
        "address_line3": "AddressLine3",
        "address_line4": "AddressLine4",
        "city": "City",
        "region": "Region",
        "postal_code": "PostalCode",
        "country": "Country",
        "attention_to": "AttentionTo",
    }

    def __init__(
        self,
        address_type=None,
        address_line1=None,
        address_line2=None,
        address_line3=None,
        address_line4=None,
        city=None,
        region=None,
        postal_code=None,
        country=None,
        attention_to=None,
    ):  # noqa: E501
        """Address - a model defined in OpenAPI"""  # noqa: E501

        self._address_type = None
        self._address_line1 = None
        self._address_line2 = None
        self._address_line3 = None
        self._address_line4 = None
        self._city = None
        self._region = None
        self._postal_code = None
        self._country = None
        self._attention_to = None
        self.discriminator = None

        if address_type is not None:
            self.address_type = address_type
        if address_line1 is not None:
            self.address_line1 = address_line1
        if address_line2 is not None:
            self.address_line2 = address_line2
        if address_line3 is not None:
            self.address_line3 = address_line3
        if address_line4 is not None:
            self.address_line4 = address_line4
        if city is not None:
            self.city = city
        if region is not None:
            self.region = region
        if postal_code is not None:
            self.postal_code = postal_code
        if country is not None:
            self.country = country
        if attention_to is not None:
            self.attention_to = attention_to

    @property
    def address_type(self):
        """Gets the address_type of this Address.  # noqa: E501

        define the type of address  # noqa: E501

        :return: The address_type of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_type

    @address_type.setter
    def address_type(self, address_type):
        """Sets the address_type of this Address.

        define the type of address  # noqa: E501

        :param address_type: The address_type of this Address.  # noqa: E501
        :type: str
        """
        allowed_values = ["POBOX", "STREET", "None"]  # noqa: E501

        if address_type:
            if address_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `address_type` ({0}), must be one of {1}".format(  # noqa: E501
                        address_type, allowed_values
                    )
                )

        self._address_type = address_type

    @property
    def address_line1(self):
        """Gets the address_line1 of this Address.  # noqa: E501

        max length = 500  # noqa: E501

        :return: The address_line1 of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """Sets the address_line1 of this Address.

        max length = 500  # noqa: E501

        :param address_line1: The address_line1 of this Address.  # noqa: E501
        :type: str
        """
        if address_line1 is not None and len(address_line1) > 500:
            raise ValueError(
                "Invalid value for `address_line1`, "
                "length must be less than or equal to `500`"
            )  # noqa: E501

        self._address_line1 = address_line1

    @property
    def address_line2(self):
        """Gets the address_line2 of this Address.  # noqa: E501

        max length = 500  # noqa: E501

        :return: The address_line2 of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """Sets the address_line2 of this Address.

        max length = 500  # noqa: E501

        :param address_line2: The address_line2 of this Address.  # noqa: E501
        :type: str
        """
        if address_line2 is not None and len(address_line2) > 500:
            raise ValueError(
                "Invalid value for `address_line2`, "
                "length must be less than or equal to `500`"
            )  # noqa: E501

        self._address_line2 = address_line2

    @property
    def address_line3(self):
        """Gets the address_line3 of this Address.  # noqa: E501

        max length = 500  # noqa: E501

        :return: The address_line3 of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_line3

    @address_line3.setter
    def address_line3(self, address_line3):
        """Sets the address_line3 of this Address.

        max length = 500  # noqa: E501

        :param address_line3: The address_line3 of this Address.  # noqa: E501
        :type: str
        """
        if address_line3 is not None and len(address_line3) > 500:
            raise ValueError(
                "Invalid value for `address_line3`, "
                "length must be less than or equal to `500`"
            )  # noqa: E501

        self._address_line3 = address_line3

    @property
    def address_line4(self):
        """Gets the address_line4 of this Address.  # noqa: E501

        max length = 500  # noqa: E501

        :return: The address_line4 of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_line4

    @address_line4.setter
    def address_line4(self, address_line4):
        """Sets the address_line4 of this Address.

        max length = 500  # noqa: E501

        :param address_line4: The address_line4 of this Address.  # noqa: E501
        :type: str
        """
        if address_line4 is not None and len(address_line4) > 500:
            raise ValueError(
                "Invalid value for `address_line4`, "
                "length must be less than or equal to `500`"
            )  # noqa: E501

        self._address_line4 = address_line4

    @property
    def city(self):
        """Gets the city of this Address.  # noqa: E501

        max length = 255  # noqa: E501

        :return: The city of this Address.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this Address.

        max length = 255  # noqa: E501

        :param city: The city of this Address.  # noqa: E501
        :type: str
        """
        if city is not None and len(city) > 255:
            raise ValueError(
                "Invalid value for `city`, "
                "length must be less than or equal to `255`"
            )  # noqa: E501

        self._city = city

    @property
    def region(self):
        """Gets the region of this Address.  # noqa: E501

        max length = 255  # noqa: E501

        :return: The region of this Address.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this Address.

        max length = 255  # noqa: E501

        :param region: The region of this Address.  # noqa: E501
        :type: str
        """
        if region is not None and len(region) > 255:
            raise ValueError(
                "Invalid value for `region`, "
                "length must be less than or equal to `255`"
            )  # noqa: E501

        self._region = region

    @property
    def postal_code(self):
        """Gets the postal_code of this Address.  # noqa: E501

        max length = 50  # noqa: E501

        :return: The postal_code of this Address.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this Address.

        max length = 50  # noqa: E501

        :param postal_code: The postal_code of this Address.  # noqa: E501
        :type: str
        """
        if postal_code is not None and len(postal_code) > 50:
            raise ValueError(
                "Invalid value for `postal_code`, "
                "length must be less than or equal to `50`"
            )  # noqa: E501

        self._postal_code = postal_code

    @property
    def country(self):
        """Gets the country of this Address.  # noqa: E501

        max length = 50, [A-Z], [a-z] only  # noqa: E501

        :return: The country of this Address.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Address.

        max length = 50, [A-Z], [a-z] only  # noqa: E501

        :param country: The country of this Address.  # noqa: E501
        :type: str
        """
        if country is not None and len(country) > 50:
            raise ValueError(
                "Invalid value for `country`, "
                "length must be less than or equal to `50`"
            )  # noqa: E501

        self._country = country

    @property
    def attention_to(self):
        """Gets the attention_to of this Address.  # noqa: E501

        max length = 255  # noqa: E501

        :return: The attention_to of this Address.  # noqa: E501
        :rtype: str
        """
        return self._attention_to

    @attention_to.setter
    def attention_to(self, attention_to):
        """Sets the attention_to of this Address.

        max length = 255  # noqa: E501

        :param attention_to: The attention_to of this Address.  # noqa: E501
        :type: str
        """
        if attention_to is not None and len(attention_to) > 255:
            raise ValueError(
                "Invalid value for `attention_to`, "
                "length must be less than or equal to `255`"
            )  # noqa: E501

        self._attention_to = attention_to



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class SuperannuationLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "super_membership_id": "str",
        "contribution_type": "SuperannuationContributionType",
        "calculation_type": "SuperannuationCalculationType",
        "minimum_monthly_earnings": "float",
        "expense_account_code": "str",
        "liability_account_code": "str",
        "payment_date_for_this_period": "date[ms-format]",
        "percentage": "float",
        "amount": "float",
    }

    attribute_map = {
        "super_membership_id": "SuperMembershipID",
        "contribution_type": "ContributionType",
        "calculation_type": "CalculationType",
        "minimum_monthly_earnings": "MinimumMonthlyEarnings",
        "expense_account_code": "ExpenseAccountCode",
        "liability_account_code": "LiabilityAccountCode",
        "payment_date_for_this_period": "PaymentDateForThisPeriod",
        "percentage": "Percentage",
        "amount": "Amount",
    }

    def __init__(
        self,
        super_membership_id=None,
        contribution_type=None,
        calculation_type=None,
        minimum_monthly_earnings=None,
        expense_account_code=None,
        liability_account_code=None,
        payment_date_for_this_period=None,
        percentage=None,
        amount=None,
    ):  # noqa: E501
        """SuperannuationLine - a model defined in OpenAPI"""  # noqa: E501

        self._super_membership_id = None
        self._contribution_type = None
        self._calculation_type = None
        self._minimum_monthly_earnings = None
        self._expense_account_code = None
        self._liability_account_code = None
        self._payment_date_for_this_period = None
        self._percentage = None
        self._amount = None
        self.discriminator = None

        if super_membership_id is not None:
            self.super_membership_id = super_membership_id
        if contribution_type is not None:
            self.contribution_type = contribution_type
        if calculation_type is not None:
            self.calculation_type = calculation_type
        if minimum_monthly_earnings is not None:
            self.minimum_monthly_earnings = minimum_monthly_earnings
        if expense_account_code is not None:
            self.expense_account_code = expense_account_code
        if liability_account_code is not None:
            self.liability_account_code = liability_account_code
        if payment_date_for_this_period is not None:
            self.payment_date_for_this_period = payment_date_for_this_period
        if percentage is not None:
            self.percentage = percentage
        if amount is not None:
            self.amount = amount

    @property
    def super_membership_id(self):
        """Gets the super_membership_id of this SuperannuationLine.  # noqa: E501

        Xero identifier for payroll super fund membership ID.  # noqa: E501

        :return: The super_membership_id of this SuperannuationLine.  # noqa: E501
        :rtype: str
        """
        return self._super_membership_id

    @super_membership_id.setter
    def super_membership_id(self, super_membership_id):
        """Sets the super_membership_id of this SuperannuationLine.

        Xero identifier for payroll super fund membership ID.  # noqa: E501

        :param super_membership_id: The super_membership_id of this SuperannuationLine.  # noqa: E501
        :type: str
        """

        self._super_membership_id = super_membership_id

    @property
    def contribution_type(self):
        """Gets the contribution_type of this SuperannuationLine.  # noqa: E501


        :return: The contribution_type of this SuperannuationLine.  # noqa: E501
        :rtype: SuperannuationContributionType
        """
        return self._contribution_type

    @contribution_type.setter
    def contribution_type(self, contribution_type):
        """Sets the contribution_type of this SuperannuationLine.


        :param contribution_type: The contribution_type of this SuperannuationLine.  # noqa: E501
        :type: SuperannuationContributionType
        """

        self._contribution_type = contribution_type

    @property
    def calculation_type(self):
        """Gets the calculation_type of this SuperannuationLine.  # noqa: E501


        :return: The calculation_type of this SuperannuationLine.  # noqa: E501
        :rtype: SuperannuationCalculationType
        """
        return self._calculation_type

    @calculation_type.setter
    def calculation_type(self, calculation_type):
        """Sets the calculation_type of this SuperannuationLine.


        :param calculation_type: The calculation_type of this SuperannuationLine.  # noqa: E501
        :type: SuperannuationCalculationType
        """

        self._calculation_type = calculation_type

    @property
    def minimum_monthly_earnings(self):
        """Gets the minimum_monthly_earnings of this SuperannuationLine.  # noqa: E501

        Superannuation minimum monthly earnings.  # noqa: E501

        :return: The minimum_monthly_earnings of this SuperannuationLine.  # noqa: E501
        :rtype: float
        """
        return self._minimum_monthly_earnings

    @minimum_monthly_earnings.setter
    def minimum_monthly_earnings(self, minimum_monthly_earnings):
        """Sets the minimum_monthly_earnings of this SuperannuationLine.

        Superannuation minimum monthly earnings.  # noqa: E501

        :param minimum_monthly_earnings: The minimum_monthly_earnings of this SuperannuationLine.  # noqa: E501
        :type: float
        """

        self._minimum_monthly_earnings = minimum_monthly_earnings

    @property
    def expense_account_code(self):
        """Gets the expense_account_code of this SuperannuationLine.  # noqa: E501

        Superannuation expense account code.  # noqa: E501

        :return: The expense_account_code of this SuperannuationLine.  # noqa: E501
        :rtype: str
        """
        return self._expense_account_code

    @expense_account_code.setter
    def expense_account_code(self, expense_account_code):
        """Sets the expense_account_code of this SuperannuationLine.

        Superannuation expense account code.  # noqa: E501

        :param expense_account_code: The expense_account_code of this SuperannuationLine.  # noqa: E501
        :type: str
        """

        self._expense_account_code = expense_account_code

    @property
    def liability_account_code(self):
        """Gets the liability_account_code of this SuperannuationLine.  # noqa: E501

        Superannuation liability account code  # noqa: E501

        :return: The liability_account_code of this SuperannuationLine.  # noqa: E501
        :rtype: str
        """
        return self._liability_account_code

    @liability_account_code.setter
    def liability_account_code(self, liability_account_code):
        """Sets the liability_account_code of this SuperannuationLine.

        Superannuation liability account code  # noqa: E501

        :param liability_account_code: The liability_account_code of this SuperannuationLine.  # noqa: E501
        :type: str
        """

        self._liability_account_code = liability_account_code

    @property
    def payment_date_for_this_period(self):
        """Gets the payment_date_for_this_period of this SuperannuationLine.  # noqa: E501

        Superannuation payment date for the current period (YYYY-MM-DD)  # noqa: E501

        :return: The payment_date_for_this_period of this SuperannuationLine.  # noqa: E501
        :rtype: date
        """
        return self._payment_date_for_this_period

    @payment_date_for_this_period.setter
    def payment_date_for_this_period(self, payment_date_for_this_period):
        """Sets the payment_date_for_this_period of this SuperannuationLine.

        Superannuation payment date for the current period (YYYY-MM-DD)  # noqa: E501

        :param payment_date_for_this_period: The payment_date_for_this_period of this SuperannuationLine.  # noqa: E501
        :type: date
        """

        self._payment_date_for_this_period = payment_date_for_this_period

    @property
    def percentage(self):
        """Gets the percentage of this SuperannuationLine.  # noqa: E501

        Superannuation percentage  # noqa: E501

        :return: The percentage of this SuperannuationLine.  # noqa: E501
        :rtype: float
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """Sets the percentage of this SuperannuationLine.

        Superannuation percentage  # noqa: E501

        :param percentage: The percentage of this SuperannuationLine.  # noqa: E501
        :type: float
        """

        self._percentage = percentage

    @property
    def amount(self):
        """Gets the amount of this SuperannuationLine.  # noqa: E501

        Superannuation amount  # noqa: E501

        :return: The amount of this SuperannuationLine.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this SuperannuationLine.

        Superannuation amount  # noqa: E501

        :param amount: The amount of this SuperannuationLine.  # noqa: E501
        :type: float
        """

        self._amount = amount



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class CourtOrderLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"court_order_type_id": "str", "amount": "float"}

    attribute_map = {"court_order_type_id": "courtOrderTypeID", "amount": "amount"}

    def __init__(self, court_order_type_id=None, amount=None):  # noqa: E501
        """CourtOrderLine - a model defined in OpenAPI"""  # noqa: E501

        self._court_order_type_id = None
        self._amount = None
        self.discriminator = None

        if court_order_type_id is not None:
            self.court_order_type_id = court_order_type_id
        if amount is not None:
            self.amount = amount

    @property
    def court_order_type_id(self):
        """Gets the court_order_type_id of this CourtOrderLine.  # noqa: E501

        Xero identifier for payroll court order type  # noqa: E501

        :return: The court_order_type_id of this CourtOrderLine.  # noqa: E501
        :rtype: str
        """
        return self._court_order_type_id

    @court_order_type_id.setter
    def court_order_type_id(self, court_order_type_id):
        """Sets the court_order_type_id of this CourtOrderLine.

        Xero identifier for payroll court order type  # noqa: E501

        :param court_order_type_id: The court_order_type_id of this CourtOrderLine.  # noqa: E501
        :type: str
        """

        self._court_order_type_id = court_order_type_id

    @property
    def amount(self):
        """Gets the amount of this CourtOrderLine.  # noqa: E501

        Amount  # noqa: E501

        :return: The amount of this CourtOrderLine.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CourtOrderLine.

        Amount  # noqa: E501

        :param amount: The amount of this CourtOrderLine.  # noqa: E501
        :type: float
        """

        self._amount = amount



# coding: utf-8

"""
    Xero Files API

    These endpoints are specific to Xero Files API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class User(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "id": "str",
        "name": "str",
        "first_name": "str",
        "last_name": "str",
        "full_name": "str",
    }

    attribute_map = {
        "id": "Id",
        "name": "Name",
        "first_name": "FirstName",
        "last_name": "LastName",
        "full_name": "FullName",
    }

    def __init__(
        self, id=None, name=None, first_name=None, last_name=None, full_name=None
    ):  # noqa: E501
        """User - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._name = None
        self._first_name = None
        self._last_name = None
        self._full_name = None
        self.discriminator = None

        self.id = id
        if name is not None:
            self.name = name
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if full_name is not None:
            self.full_name = full_name

    @property
    def id(self):
        """Gets the id of this User.  # noqa: E501

        Xero identifier  # noqa: E501

        :return: The id of this User.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this User.

        Xero identifier  # noqa: E501

        :param id: The id of this User.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this User.  # noqa: E501

        Key is Name, but returns Email address of user who created the file  # noqa: E501

        :return: The name of this User.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this User.

        Key is Name, but returns Email address of user who created the file  # noqa: E501

        :param name: The name of this User.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def first_name(self):
        """Gets the first_name of this User.  # noqa: E501

        First name of user  # noqa: E501

        :return: The first_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this User.

        First name of user  # noqa: E501

        :param first_name: The first_name of this User.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this User.  # noqa: E501

        Last name of user  # noqa: E501

        :return: The last_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this User.

        Last name of user  # noqa: E501

        :param last_name: The last_name of this User.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def full_name(self):
        """Gets the full_name of this User.  # noqa: E501

        Last name of user  # noqa: E501

        :return: The full_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this User.

        Last name of user  # noqa: E501

        :param full_name: The full_name of this User.  # noqa: E501
        :type: str
        """

        self._full_name = full_name



# -*- coding: utf-8 -*-
from contextlib import contextmanager
from datetime import date, datetime, timedelta
from decimal import Decimal
from enum import Enum
from unittest import mock

import pytest
from dateutil import tz

from tests import FakeClass, FakeMethod
from xero_python.api_client.deserializer import (
    deserialize,
    deserialize_bool,
    deserialize_date,
    deserialize_date_ms,
    deserialize_datetime,
    deserialize_datetime_ms,
    deserialize_decimal,
    deserialize_int,
    deserialize_list,
    deserialize_model,
    deserialize_routing,
    deserialize_str,
)


@contextmanager
def mock_deserialize(name="deserialize"):
    def sub_response(key, value, model_finder):
        return value

    with mock.patch(
        "xero_python.api_client.deserializer.{}".format(name), side_effect=sub_response
    ) as deserialize:
        yield deserialize


# deserialize_routing tests
@pytest.mark.parametrize(
    "data_type", ["str", "int", "bool", "float", "date", "datetime", "User"]
)
def test_deserialize_routing(data_type):
    # given plain data type
    # when finding deserialize routing key
    key = deserialize_routing(data_type, data=None, model_finder=None)
    # then expected data_type to be key
    assert key == data_type


@pytest.mark.parametrize(
    "data_type", ["list[{}]".format(key) for key in ("str", "User")]
)
def test_deserialize_routing_list(data_type):
    # given list data type
    # when finding deserialize routing key
    key = deserialize_routing(data_type, data=None, model_finder=None)
    # then expected key to be 'list'
    assert key == "list"


# deserialize tests
def test_deserialize():
    # given default deserialize function
    default_deserialize = deserialize.registry[""]  # get default implementation
    data = {"field": "value"}

    class User:
        pass

    model_finder = FakeClass()
    model_finder.find_model = FakeMethod(return_value=User)
    # when finding deserialize routing key
    with mock_deserialize("deserialize_model") as deserialize_model:
        result = default_deserialize("User", data, model_finder)

    # then expect find_model called
    assert len(model_finder.find_model.calls) == 1
    call_args, call_kwargs = model_finder.find_model.calls[0]
    assert call_args == ("User",)
    assert call_kwargs == {}
    # then expect deserialize_mode called
    deserialize_model.assert_called_once_with(User, data, model_finder)
    # then expected result to returned from deserialize_model()
    assert result is data


# deserialize_list tests
def test_deserialize_list():
    # given proper data type
    data_type = "list[number]"
    data = (1, 2, 3, 4)
    model_finder = None
    # when deserialize list of items
    with mock_deserialize() as deserialize:
        result = deserialize_list(data_type, data, model_finder)
    # then expected deserialized list result
    assert isinstance(result, list)
    assert len(result) == len(data)
    assert result == list(data)
    deserialize.assert_has_calls([mock.call("number", i, None) for i in data])


def test_deserialize_list_key_error():
    # given invalid data type key
    data_type = "list[number"
    data = (1, 2, 3, 4)
    model_finder = None
    # when deserialize list of items
    with pytest.raises(ValueError):
        deserialize_list(data_type, data, model_finder)


# deserialize_int tests
@pytest.mark.parametrize("data,expected", [(n, int(n)) for n in ("1", "-1", 2)])
def test_deserialize_int(data, expected):
    # given data type int
    data_type = "int"
    # when deserialize integer
    result = deserialize_int(data_type, data, model_finder=None)
    # then expect result to be integer
    assert isinstance(result, int)
    assert result == expected


# deserialize_decimal tests
@pytest.mark.parametrize(
    "data,expected", [(n, Decimal(n)) for n in ("1.04", "-1.1", Decimal("0.032"))]
)
def test_deserialize_decimal(data, expected):
    # given data type float
    data_type = "float"
    # when deserialize decimal
    result = deserialize_decimal(data_type, data, model_finder=None)
    # then expect result to be Decimal
    assert isinstance(result, Decimal)
    assert result == expected


# deserialize_str tests
@pytest.mark.parametrize("data,expected", [(s, str(s)) for s in (1, True, "text")])
def test_deserialize_str(data, expected):
    # given data type string
    data_type = "str"
    # when deserialize string
    result = deserialize_str(data_type, data, model_finder=None)
    # then expect result to be string
    assert isinstance(result, str)
    assert result == expected


# deserialize_bool tests
@pytest.mark.parametrize("data,expected", [(True, True), (False, False)])
def test_deserialize_bool(data, expected):
    # given data type bool
    data_type = "bool"
    # when deserialize bool
    result = deserialize_bool(data_type, data, model_finder=None)
    # then expect result to be boolean
    assert isinstance(result, bool)
    assert result == expected


@pytest.mark.parametrize("data", [None, "", "1", "0", 1, 0])
def test_deserialize_bool_error(data):
    # given data type bool
    data_type = "bool"
    # when deserialize bool
    with pytest.raises(ValueError):
        deserialize_bool(data_type, data, model_finder=None)


# deserialize_date tests
@pytest.mark.parametrize(
    "data,expected",
    [
        ("2020-04-03", date(2020, 4, 3)),
        ("2020-02-28", date(2020, 2, 28)),
        ("2019-08-01", date(2019, 8, 1)),
    ],
)
def test_deserialize_date(data, expected):
    # given data type date
    data_type = "date"
    # when deserialize date
    result = deserialize_date(data_type, data, model_finder=None)
    # then expect result to be date
    assert isinstance(result, date)
    assert result == expected


@pytest.mark.parametrize("data", [None, "", "2019-oo-01"])
def test_deserialize_date_error(data):
    # given data type date
    data_type = "date"
    # when deserialize date
    with pytest.raises(ValueError):
        deserialize_date(data_type, data, model_finder=None)


# deserialize_date_ms tests
@pytest.mark.parametrize(
    "data,expected",
    [
        ("/Date(1511827200000+0000)/", date(2017, 11, 28)),
        ("/Date(1511827200000-0500)/", date(2017, 11, 28)),
        ("/Date(315619200000+0000)/", date(1980, 1, 2)),
        ("/Date(1550899400362)/", date(2019, 2, 23)),
        ("/Date(1550899400362+1300)/", date(2019, 2, 23)),
    ],
)
def test_deserialize_date_ms(data, expected):
    # given data type date in MS json format
    data_type = "date[ms-format]"
    # when deserialize date
    result = deserialize_date_ms(data_type, data, model_finder=None)
    # then expect result to be date
    assert isinstance(result, date)
    assert result == expected


@pytest.mark.parametrize("data", [None, "" "Date(1511827200000)"])
def test_deserialize_date_ms_error(data):
    # given data type date in MS json format
    data_type = "date[ms-format]"
    # when deserialize date
    with pytest.raises(ValueError):
        deserialize_date_ms(data_type, data, model_finder=None)


# deserialize_datetime tests
@pytest.mark.parametrize(
    "data,expected",
    [
        ("2020-04-03T05:35:06", datetime(2020, 4, 3, 5, 35, 6, tzinfo=tz.UTC)),
        ("2020-02-28 11:02:54", datetime(2020, 2, 28, 11, 2, 54, tzinfo=tz.UTC)),
        ("2019-12-10T12:59:59Z", datetime(2019, 12, 10, 12, 59, 59, tzinfo=tz.UTC)),
        (
            "2019-12-07T18:46:19.5187840",
            datetime(2019, 12, 7, 18, 46, 19, 518784, tzinfo=tz.UTC),
        ),
        (
            "2019-12-07T18:46:19.5187840Z",
            datetime(2019, 12, 7, 18, 46, 19, 518784, tzinfo=tz.UTC),
        ),
        (
            "2016-10-14T09:13:36.437000+13:00",
            datetime(
                2016,
                10,
                14,
                9,
                13,
                36,
                437000,
                tzinfo=tz.tzoffset(None, timedelta(hours=13)),
            ),
        ),
    ],
)
def test_deserialize_datetime(data, expected):
    # given data type datetime
    data_type = "datetime"
    # when deserialize datetime
    result = deserialize_datetime(data_type, data, model_finder=None)
    # then expect result to be datetime
    assert isinstance(result, datetime)
    assert result == expected


@pytest.mark.parametrize("data", [None, "", "invalid"])
def test_deserialize_datetime_error(data):
    # given data type datetime
    data_type = "datetime"
    # when deserialize datetime
    with pytest.raises(ValueError):
        deserialize_datetime(data_type, data, model_finder=None)


# deserialize_datetime_ms tests
@pytest.mark.parametrize(
    "data,expected",
    [
        (
            "/Date(1439434356790)/",
            datetime(2015, 8, 13, 2, 52, 36, 790000, tzinfo=tz.UTC),
        ),
        (
            "/Date(1439434356790+0000)/",
            datetime(2015, 8, 13, 2, 52, 36, 790000, tzinfo=tz.UTC),
        ),
        (
            "/Date(1476389616437+0000)/",
            datetime(2016, 10, 13, 20, 13, 36, 437000, tzinfo=tz.UTC),
        ),
        (
            "/Date(1476389616437+1300)/",
            datetime(
                2016,
                10,
                14,
                9,
                13,
                36,
                437000,
                tzinfo=tz.tzoffset(None, timedelta(hours=13)),
            ),
        ),
    ],
)
def test_deserialize_datetime_ms(data, expected):
    # given data type datetime in MS json format
    data_type = "datetime[ms-format]"
    # when deserialize datetime
    result = deserialize_datetime_ms(data_type, data, model_finder=None)
    # then expect result to be datetime
    assert isinstance(result, datetime)
    assert result == expected


@pytest.mark.parametrize("data", [None, "", "Date(1439434356790+0000/"])
def test_deserialize_datetime_ms_error(data):
    # given data type datetime in MS json format
    data_type = "datetime[ms-format]"
    # when deserialize datetime
    with pytest.raises(ValueError):
        deserialize_datetime_ms(data_type, data, model_finder=None)


# deserialize_model tests
def test_deserialize_model():
    # given test model and test data
    data = {"Value": 132, "Short": "short description"}

    class Model:
        openapi_types = {"value": "int", "description": "str"}
        attribute_map = {"value": "Value", "description": "Short"}

        def __init__(self, **kwargs):
            self.kwargs = kwargs

    # when deserialize model
    with mock_deserialize() as deserialize:
        result = deserialize_model(Model, data, model_finder=None)
    # then expect result to be model
    assert isinstance(result, Model)
    assert result.kwargs == {"value": 132, "description": "short description"}
    deserialize.assert_any_call("int", 132, None)
    deserialize.assert_any_call("str", "short description", None)


@pytest.mark.parametrize("data", [None, "", 1, True])
def test_deserialize_model_error(data):
    # given test model and invalid test data
    class Model:
        openapi_types = {"value": "int", "description": "str"}

    # when deserialize model
    with pytest.raises(ValueError):
        deserialize_model(Model, data, model_finder=None)


class Shape(Enum):
    """
    Test enum class to mimic Enum API model
    """

    SQUARE = "square"
    DIAMOND = "diamond"
    CIRCLE = "circle"


@pytest.mark.parametrize(
    "data,expected",
    [("square", Shape.SQUARE), ("diamond", Shape.DIAMOND), ("circle", Shape.CIRCLE)],
)
def test_deserialize_model_enum(data, expected):
    # given test enum model and enum value
    # when deserialize model
    result = deserialize_model(Shape, data, model_finder=None)
    # then correct Shape enum expected
    assert isinstance(result, Shape)
    assert result == expected



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ContactPerson(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "first_name": "str",
        "last_name": "str",
        "email_address": "str",
        "include_in_emails": "bool",
    }

    attribute_map = {
        "first_name": "FirstName",
        "last_name": "LastName",
        "email_address": "EmailAddress",
        "include_in_emails": "IncludeInEmails",
    }

    def __init__(
        self,
        first_name=None,
        last_name=None,
        email_address=None,
        include_in_emails=None,
    ):  # noqa: E501
        """ContactPerson - a model defined in OpenAPI"""  # noqa: E501

        self._first_name = None
        self._last_name = None
        self._email_address = None
        self._include_in_emails = None
        self.discriminator = None

        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email_address is not None:
            self.email_address = email_address
        if include_in_emails is not None:
            self.include_in_emails = include_in_emails

    @property
    def first_name(self):
        """Gets the first_name of this ContactPerson.  # noqa: E501

        First name of person  # noqa: E501

        :return: The first_name of this ContactPerson.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this ContactPerson.

        First name of person  # noqa: E501

        :param first_name: The first_name of this ContactPerson.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this ContactPerson.  # noqa: E501

        Last name of person  # noqa: E501

        :return: The last_name of this ContactPerson.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this ContactPerson.

        Last name of person  # noqa: E501

        :param last_name: The last_name of this ContactPerson.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email_address(self):
        """Gets the email_address of this ContactPerson.  # noqa: E501

        Email address of person  # noqa: E501

        :return: The email_address of this ContactPerson.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this ContactPerson.

        Email address of person  # noqa: E501

        :param email_address: The email_address of this ContactPerson.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def include_in_emails(self):
        """Gets the include_in_emails of this ContactPerson.  # noqa: E501

        boolean to indicate whether contact should be included on emails with invoices etc.  # noqa: E501

        :return: The include_in_emails of this ContactPerson.  # noqa: E501
        :rtype: bool
        """
        return self._include_in_emails

    @include_in_emails.setter
    def include_in_emails(self, include_in_emails):
        """Sets the include_in_emails of this ContactPerson.

        boolean to indicate whether contact should be included on emails with invoices etc.  # noqa: E501

        :param include_in_emails: The include_in_emails of this ContactPerson.  # noqa: E501
        :type: bool
        """

        self._include_in_emails = include_in_emails



# coding: utf-8

"""
    Xero Projects API

    This is the Xero Projects API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TaskCreateOrUpdate(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "name": "str",
        "rate": "Amount",
        "charge_type": "ChargeType",
        "estimate_minutes": "int",
    }

    attribute_map = {
        "name": "name",
        "rate": "rate",
        "charge_type": "chargeType",
        "estimate_minutes": "estimateMinutes",
    }

    def __init__(
        self, name=None, rate=None, charge_type=None, estimate_minutes=None
    ):  # noqa: E501
        """TaskCreateOrUpdate - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._rate = None
        self._charge_type = None
        self._estimate_minutes = None
        self.discriminator = None

        self.name = name
        self.rate = rate
        self.charge_type = charge_type
        if estimate_minutes is not None:
            self.estimate_minutes = estimate_minutes

    @property
    def name(self):
        """Gets the name of this TaskCreateOrUpdate.  # noqa: E501

        Name of the task. Max length 100 characters.  # noqa: E501

        :return: The name of this TaskCreateOrUpdate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaskCreateOrUpdate.

        Name of the task. Max length 100 characters.  # noqa: E501

        :param name: The name of this TaskCreateOrUpdate.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def rate(self):
        """Gets the rate of this TaskCreateOrUpdate.  # noqa: E501


        :return: The rate of this TaskCreateOrUpdate.  # noqa: E501
        :rtype: Amount
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """Sets the rate of this TaskCreateOrUpdate.


        :param rate: The rate of this TaskCreateOrUpdate.  # noqa: E501
        :type: Amount
        """
        if rate is None:
            raise ValueError(
                "Invalid value for `rate`, must not be `None`"
            )  # noqa: E501

        self._rate = rate

    @property
    def charge_type(self):
        """Gets the charge_type of this TaskCreateOrUpdate.  # noqa: E501


        :return: The charge_type of this TaskCreateOrUpdate.  # noqa: E501
        :rtype: ChargeType
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this TaskCreateOrUpdate.


        :param charge_type: The charge_type of this TaskCreateOrUpdate.  # noqa: E501
        :type: ChargeType
        """
        if charge_type is None:
            raise ValueError(
                "Invalid value for `charge_type`, must not be `None`"
            )  # noqa: E501

        self._charge_type = charge_type

    @property
    def estimate_minutes(self):
        """Gets the estimate_minutes of this TaskCreateOrUpdate.  # noqa: E501

        Estimated time to perform the task. EstimateMinutes has to be greater than 0 if provided.  # noqa: E501

        :return: The estimate_minutes of this TaskCreateOrUpdate.  # noqa: E501
        :rtype: int
        """
        return self._estimate_minutes

    @estimate_minutes.setter
    def estimate_minutes(self, estimate_minutes):
        """Sets the estimate_minutes of this TaskCreateOrUpdate.

        Estimated time to perform the task. EstimateMinutes has to be greater than 0 if provided.  # noqa: E501

        :param estimate_minutes: The estimate_minutes of this TaskCreateOrUpdate.  # noqa: E501
        :type: int
        """

        self._estimate_minutes = estimate_minutes



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Element(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "validation_errors": "list[ValidationError]",
        "batch_payment_id": "str",
        "bank_transaction_id": "str",
        "credit_note_id": "str",
        "contact_id": "str",
        "invoice_id": "str",
        "item_id": "str",
        "purchase_order_id": "str",
    }

    attribute_map = {
        "validation_errors": "ValidationErrors",
        "batch_payment_id": "BatchPaymentID",
        "bank_transaction_id": "BankTransactionID",
        "credit_note_id": "CreditNoteID",
        "contact_id": "ContactID",
        "invoice_id": "InvoiceID",
        "item_id": "ItemID",
        "purchase_order_id": "PurchaseOrderID",
    }

    def __init__(
        self,
        validation_errors=None,
        batch_payment_id=None,
        bank_transaction_id=None,
        credit_note_id=None,
        contact_id=None,
        invoice_id=None,
        item_id=None,
        purchase_order_id=None,
    ):  # noqa: E501
        """Element - a model defined in OpenAPI"""  # noqa: E501

        self._validation_errors = None
        self._batch_payment_id = None
        self._bank_transaction_id = None
        self._credit_note_id = None
        self._contact_id = None
        self._invoice_id = None
        self._item_id = None
        self._purchase_order_id = None
        self.discriminator = None

        if validation_errors is not None:
            self.validation_errors = validation_errors
        if batch_payment_id is not None:
            self.batch_payment_id = batch_payment_id
        if bank_transaction_id is not None:
            self.bank_transaction_id = bank_transaction_id
        if credit_note_id is not None:
            self.credit_note_id = credit_note_id
        if contact_id is not None:
            self.contact_id = contact_id
        if invoice_id is not None:
            self.invoice_id = invoice_id
        if item_id is not None:
            self.item_id = item_id
        if purchase_order_id is not None:
            self.purchase_order_id = purchase_order_id

    @property
    def validation_errors(self):
        """Gets the validation_errors of this Element.  # noqa: E501

        Array of Validation Error message  # noqa: E501

        :return: The validation_errors of this Element.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this Element.

        Array of Validation Error message  # noqa: E501

        :param validation_errors: The validation_errors of this Element.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors

    @property
    def batch_payment_id(self):
        """Gets the batch_payment_id of this Element.  # noqa: E501

        Unique ID for batch payment object with validation error  # noqa: E501

        :return: The batch_payment_id of this Element.  # noqa: E501
        :rtype: str
        """
        return self._batch_payment_id

    @batch_payment_id.setter
    def batch_payment_id(self, batch_payment_id):
        """Sets the batch_payment_id of this Element.

        Unique ID for batch payment object with validation error  # noqa: E501

        :param batch_payment_id: The batch_payment_id of this Element.  # noqa: E501
        :type: str
        """

        self._batch_payment_id = batch_payment_id

    @property
    def bank_transaction_id(self):
        """Gets the bank_transaction_id of this Element.  # noqa: E501


        :return: The bank_transaction_id of this Element.  # noqa: E501
        :rtype: str
        """
        return self._bank_transaction_id

    @bank_transaction_id.setter
    def bank_transaction_id(self, bank_transaction_id):
        """Sets the bank_transaction_id of this Element.


        :param bank_transaction_id: The bank_transaction_id of this Element.  # noqa: E501
        :type: str
        """

        self._bank_transaction_id = bank_transaction_id

    @property
    def credit_note_id(self):
        """Gets the credit_note_id of this Element.  # noqa: E501


        :return: The credit_note_id of this Element.  # noqa: E501
        :rtype: str
        """
        return self._credit_note_id

    @credit_note_id.setter
    def credit_note_id(self, credit_note_id):
        """Sets the credit_note_id of this Element.


        :param credit_note_id: The credit_note_id of this Element.  # noqa: E501
        :type: str
        """

        self._credit_note_id = credit_note_id

    @property
    def contact_id(self):
        """Gets the contact_id of this Element.  # noqa: E501


        :return: The contact_id of this Element.  # noqa: E501
        :rtype: str
        """
        return self._contact_id

    @contact_id.setter
    def contact_id(self, contact_id):
        """Sets the contact_id of this Element.


        :param contact_id: The contact_id of this Element.  # noqa: E501
        :type: str
        """

        self._contact_id = contact_id

    @property
    def invoice_id(self):
        """Gets the invoice_id of this Element.  # noqa: E501


        :return: The invoice_id of this Element.  # noqa: E501
        :rtype: str
        """
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, invoice_id):
        """Sets the invoice_id of this Element.


        :param invoice_id: The invoice_id of this Element.  # noqa: E501
        :type: str
        """

        self._invoice_id = invoice_id

    @property
    def item_id(self):
        """Gets the item_id of this Element.  # noqa: E501


        :return: The item_id of this Element.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this Element.


        :param item_id: The item_id of this Element.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def purchase_order_id(self):
        """Gets the purchase_order_id of this Element.  # noqa: E501


        :return: The purchase_order_id of this Element.  # noqa: E501
        :rtype: str
        """
        return self._purchase_order_id

    @purchase_order_id.setter
    def purchase_order_id(self, purchase_order_id):
        """Sets the purchase_order_id of this Element.


        :param purchase_order_id: The purchase_order_id of this Element.  # noqa: E501
        :type: str
        """

        self._purchase_order_id = purchase_order_id



# coding: utf-8

# flake8: noqa

"""
    Xero Assets API

    The Assets API exposes fixed asset related functions of the Xero Accounting application and can be used for a variety of purposes such as creating assets, retrieving asset valuations etc.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


# import apis into sdk package
from xero_python.assets.api.asset_api import AssetApi


# import models into sdk package
from xero_python.assets.models.asset import Asset
from xero_python.assets.models.asset_status import AssetStatus
from xero_python.assets.models.asset_status_query_param import AssetStatusQueryParam
from xero_python.assets.models.asset_type import AssetType
from xero_python.assets.models.assets import Assets
from xero_python.assets.models.book_depreciation_detail import BookDepreciationDetail
from xero_python.assets.models.book_depreciation_setting import BookDepreciationSetting
from xero_python.assets.models.error import Error
from xero_python.assets.models.field_validation_errors_element import (
    FieldValidationErrorsElement,
)
from xero_python.assets.models.pagination import Pagination
from xero_python.assets.models.resource_validation_errors_element import (
    ResourceValidationErrorsElement,
)
from xero_python.assets.models.setting import Setting
